@@ -3,6 +3,7 @@ use strict;
 use warnings;
 
 our @LOGS;
+our @ILOGS;
 our @ELOGS;
 
 sub new {
@@ -14,6 +15,11 @@ sub debug {
     push(@LOGS, shift());
 }
 
+sub info {
+    shift;
+    push(@ILOGS, shift());
+}
+
 sub warn {
     shift;
     push(@ELOGS, shift());
